@@ -18,7 +18,7 @@ import textwrap
 import time
 from urllib.request import urlopen
 
-__version__ = "1.0"
+__version__ = "1.1"
 
 DOCKER_NS = "satex"
 REGISTRY_URL = "https://github.com/sat-heritage/docker-images/releases/download/list/list.tgz"
@@ -321,6 +321,10 @@ def easy_volume(v):
         v = f"{orig}:{dest}"
     return v
 
+def get_docker_volumes(args):
+    opts = getattr(args, "volume") or []
+    return [easy_volume(opt).split(":") for opt in opts]
+
 _docker_opts = []
 def docker_runs(args, images, docker_args=(), image_args=()):
     docker_argv = check_docker()
@@ -397,7 +401,34 @@ def run_images(args):
 
 def runraw_images(args):
     images = get_list(args)
-    ret = docker_runs(args, images, image_args=["--raw"]+args.args)
+    # automatically tries to detect filenames and make volumes
+    volumes = [v[1] for v in get_docker_volumes(args)]
+    volume = "/data"
+    i = 1
+    while volume in volumes:
+        volume = f"/data{i}"
+        i += 1
+    paths = []
+    docker_args = []
+    for arg in args.args:
+        if os.path.exists(arg):
+            path = Path(arg).resolve()
+            if not os.path.isdir(arg):
+                path = path.parent
+            paths.append(path)
+    if paths:
+        root = Path(os.path.commonpath(paths))
+        warn(f"Mounting {root} as {volume}")
+        docker_args = ["-v", f"{root.as_posix()}:{volume}"]
+    def update_path(path):
+        if not os.path.exists(path):
+            return path
+        r = Path(path).resolve().relative_to(root).as_posix()
+        r = os.path.join(volume, r)
+        warn(f"Argument '{path}' detected as a local path, it has been rewritten to {r}")
+        return r
+    image_args = ["--raw"] + [update_path(arg) for arg in args.args]
+    ret = docker_runs(args, images, docker_args, image_args)
     if ret is not None:
         sys.exit(ret)
 
@@ -606,7 +637,7 @@ def test_images(args):
     else:
         print(red("Failed tests:"))
         for image, fails in failures:
-            print(f"{lightred(image.name)} failed tests {' '.join(fails)}")
+            print(f"{image.name} failed tests {' '.join(fails)}")
 
     if failures:
         sys.exit(1)
